@@ -44,6 +44,47 @@
   (require 'pcase))
 
 
+;; ---------------------------------------------------------------------------
+;; Compatibility
+
+(when (and (version< emacs-version "31.1") (not (and (fboundp 'incf) (fboundp 'decf))))
+  (defmacro incf (place &optional delta)
+    "Increment PLACE by DELTA or 1."
+    (declare (debug (gv-place &optional form)))
+    (gv-letplace (getter setter) place
+      (funcall setter `(+ ,getter ,(or delta 1)))))
+  (defmacro decf (place &optional delta)
+    "Decrement PLACE by DELTA or 1."
+    (declare (debug (gv-place &optional form)))
+    (gv-letplace (getter setter) place
+      (funcall setter `(- ,getter ,(or delta 1))))))
+
+;; Workaround bug in Emacs 30, where this macro fails when to enable
+;; auto-compression-mode when a file is loaded from the command line.
+;; The problem seems to be `auto-compression-mode' is true,
+;; but the mode has not started when undo-fu-session runs.
+;; Workaround the bug by replacing the auto-compression-mode
+;; check with `jka-compr-installed-p'.
+;; I didn't manage to redo this in simple test cases (for a report),
+;; so use a workaround for now.
+(defmacro undo-fu-session--with-auto-compression-mode (&rest body)
+  "Evaluate BODY with automatic file compression and uncompression enabled."
+  (declare (indent 0))
+  (let ((already-installed (make-symbol "already-installed"))
+        (already-installed-value (make-symbol "already-installed-value")))
+    `(let ((,already-installed (jka-compr-installed-p))
+           (,already-installed-value auto-compression-mode))
+       (unwind-protect
+           (progn
+             (unless ,already-installed
+               (auto-compression-mode 1))
+             ,@body)
+         (unless (or ,already-installed)
+           (auto-compression-mode -1))
+         ;; Restore the initial state (even if it's inconsistent).
+         (setq auto-compression-mode ,already-installed-value)))))
+
+
 ;; ---------------------------------------------------------------------------
 ;; Custom variables.
 
@@ -113,36 +154,6 @@ Enforcing removes the oldest files."
   :type 'integer)
 
 
-;; ---------------------------------------------------------------------------
-;; Compatibility
-;;
-
-;; Workaround bug in Emacs 30, where this macro fails when to enable
-;; auto-compression-mode when a file is loaded from the command line.
-;; The problem seems to be `auto-compression-mode' is true,
-;; but the mode has not started when undo-fu-session runs.
-;; Workaround the bug by replacing the auto-compression-mode
-;; check with `jka-compr-installed-p'.
-;; I didn't manage to redo this in simple test cases (for a report),
-;; so use a workaround for now.
-(defmacro undo-fu-session--with-auto-compression-mode (&rest body)
-  "Evaluate BODY with automatic file compression and uncompression enabled."
-  (declare (indent 0))
-  (let ((already-installed (make-symbol "already-installed"))
-        (already-installed-value (make-symbol "already-installed-value")))
-    `(let ((,already-installed (jka-compr-installed-p))
-           (,already-installed-value auto-compression-mode))
-       (unwind-protect
-           (progn
-             (unless ,already-installed
-               (auto-compression-mode 1))
-             ,@body)
-         (unless (or ,already-installed)
-           (auto-compression-mode -1))
-         ;; Restore the initial state (even if it's inconsistent).
-         (setq auto-compression-mode ,already-installed-value)))))
-
-
 ;; ---------------------------------------------------------------------------
 ;; Utility Functions
 ;;
@@ -343,7 +354,7 @@ List elements are used as keys mapping to INDEX by INDEX-STEP."
   (unless (eq list t)
     (while list
       (puthash list index step-to-index-hash)
-      (setq index (+ index index-step))
+      (incf index index-step)
       (setq list (undo-fu-session--next-step list)))))
 
 (defun undo-fu-session--list-from-index-map (list index index-step step-from-index-hash)
@@ -354,7 +365,7 @@ INDEX-STEP are used as keys mapping to LIST elements."
   (unless (eq list t)
     (while list
       (puthash index list step-from-index-hash)
-      (setq index (+ index index-step))
+      (incf index index-step)
       (setq list (undo-fu-session--next-step list)))))
 
 (defun undo-fu-session--equivtable-encode (equiv-table buffer-list pending-list)
@@ -475,7 +486,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
       (let ((file-src-full (file-name-concat undo-fu-session-directory file-src)))
         (unless (file-directory-p file-src-full)
           (unless (string-suffix-p ext-dst file-src)
-            (setq count-pending (1+ count-pending))
+            (incf count-pending)
             (push file-src-full files-to-convert)))))
 
     (message "Operating on %d file(s) in \"%s\"" count-pending undo-fu-session-directory)
@@ -506,11 +517,11 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
                   (let ((create-lockfiles nil))
                     (write-region nil nil file-dst-full nil 0)))
 
-                (setq size-src (+ size-src (file-attribute-size (file-attributes file-src-full))))
-                (setq size-dst (+ size-dst (file-attribute-size (file-attributes file-dst-full))))
+                (incf size-src (file-attribute-size (file-attributes file-src-full)))
+                (incf size-dst (file-attribute-size (file-attributes file-dst-full)))
 
                 (delete-file file-src-full)
-                (setq count-complete (1+ count-complete)))
+                (incf count-complete))
 
             (error
              (message "Error: %s" (error-message-string err)))))))
